#include "general/AtExit.hh"

#include "Catalog.hh"
#include "Channel.hh"

FrameAPI::Catalog::stream_source_type	frame_files;

void Initialize( );
void TestOpenData( );

int
main( int ArgC, char** ArgV )
{
  Initialize( );

  TestOpenData( );

  General::AtExit::Cleanup( );

  return 0;
}

void
Initialize( )
{
  frame_files.push_back( "/home/emaros/tmp/H-SIDv1_H1H2_250mHz-821935753-26.gwf" );
}

void
TestOpenData( )
{
  try
  {
    FrameAPI::Catalog::gps_seconds_type		start( 821935753);
    FrameAPI::Catalog::gps_seconds_type		stop( start + 16 );
    FrameAPI::Catalog::channel_name_type	channel_names;

    //-------------------------------------------------------------------
    // Open, scan the TOC, and close a set of files.
    // This gets the meta data located in the TOC and makes it available
    //   to the caller via the catalog interface
    //-------------------------------------------------------------------
    FrameAPI::Catalog catalog( frame_files );
    //-------------------------------------------------------------------
    // Display the data range
    //-------------------------------------------------------------------
    std::cout << "start time: " << catalog.GPSStartTime( ) << std::endl;
    std::cout << "end time: " << catalog.GPSEndTime( ) << std::endl;
    //-------------------------------------------------------------------
    // Obtain the catalog of channels
    //-------------------------------------------------------------------
    FrameAPI::Catalog::channel_dict_type
      channelDict = catalog.Channels( );
    for ( FrameAPI::Catalog::channel_dict_type::element_type::const_iterator
	    cur = channelDict->begin( ),
	    last = channelDict->end( );
	  cur != last;
	  ++cur )
    {
      std::cout << "Channel: " << cur->first
		<< std::endl;
    }
    //------------------------------------------------------------------
    // Read a collection of channels
    //------------------------------------------------------------------
    // channel_names.push_back( "H1H2:CSD" ); // not available
    channel_names.push_back( "H1:AdjacentPSD" );
    FrameAPI::Catalog::data_dict_type
      dataDict( catalog.Fetch( start, stop, channel_names ) );
#if 0 || 1
    //------------------------------------------------------------------
    // Display some meta data about the channels
    //------------------------------------------------------------------
    FrameAPI::Catalog::DataDictionary::channel_type
      channel( (*dataDict)[ channel_names[ 0 ] ] );
    std::cout << "Channel: unitY: " << channel->GetUnitY( )
	      << std::endl
      ;
#endif /* 0 */
  }
  catch( const std::exception& E )
  {
    std::cerr << E.what( ) << std::endl;
  }
}
